==> python_fm_dapi_weaver-0.1.4.tar.gz: python_fm_dapi_weaver-0.1.4/CHANGELOG.md <==
# CHANGELOG


## v0.1.4 (2025-05-14)


## v0.1.3 (2025-05-14)

### Bug Fixes

- Update readme
  ([`9b3ae8c`](https://github.com/mindfiredigital/python-fm-dapi-weaver/commit/9b3ae8c64351ed6cd10d8d9b46cd9f9ee9c44688))


## v0.1.2 (2025-05-14)

### Bug Fixes

- Update readme
  ([`8686199`](https://github.com/mindfiredigital/python-fm-dapi-weaver/commit/8686199110eb74b222ef940f1ce400d0ccecd448))

- Update readme
  ([`abc4771`](https://github.com/mindfiredigital/python-fm-dapi-weaver/commit/abc4771319e1912b51fc02255f2936fcc8092ce9))


## v0.1.1 (2025-05-14)


## v0.1.0 (2025-05-14)

### Bug Fixes

- Add releaseerc
  ([`1970ac8`](https://github.com/mindfiredigital/python-fm-dapi-weaver/commit/1970ac8c22c9164e76147855ebe2a8904c8534f6))

- Add version in init.py
  ([`11ce3f3`](https://github.com/mindfiredigital/python-fm-dapi-weaver/commit/11ce3f33ae8d513eea5229ee1ff54c233e71cfbe))

- Update readme
  ([`fdb655f`](https://github.com/mindfiredigital/python-fm-dapi-weaver/commit/fdb655f6d68fa201bcf90c7615cedff41e60c478))

- Update setup file - Merge pull request #9 from CSWorldTelugu/master
  ([`484feca`](https://github.com/mindfiredigital/python-fm-dapi-weaver/commit/484fecaab3536242e846f3e65e5b4c94058f0f03))

update setup file

- Update setup.cfg
  ([`f03efb7`](https://github.com/mindfiredigital/python-fm-dapi-weaver/commit/f03efb72d7278c84189eec94536720d0e1beb55b))

- Update workflow.yml
  ([`39e803d`](https://github.com/mindfiredigital/python-fm-dapi-weaver/commit/39e803d95b5f80e8b1f319bcf90328c6f466a712))

- Update workflow.yml to raise PR to main from master
  ([`aed95e6`](https://github.com/mindfiredigital/python-fm-dapi-weaver/commit/aed95e6cf095dc811ccfcc9592a99aa4517719e3))

### Features

- Initial release
  ([`7093c0c`](https://github.com/mindfiredigital/python-fm-dapi-weaver/commit/7093c0c0e17ab7883208549989192b9988f17634))

==> python_fm_dapi_weaver-0.1.5.tar.gz: python_fm_dapi_weaver-0.1.5/CHANGELOG.md <==
# CHANGELOG


## v0.1.5 (2025-05-14)

### Bug Fixes

- Update workflow
  ([`f34bd57`](https://github.com/mindfiredigital/python-fm-dapi-weaver/commit/f34bd5724941817782111dda6089021b540292e7))


## v0.1.4 (2025-05-14)


## v0.1.3 (2025-05-14)

### Bug Fixes

- Update readme
  ([`9b3ae8c`](https://github.com/mindfiredigital/python-fm-dapi-weaver/commit/9b3ae8c64351ed6cd10d8d9b46cd9f9ee9c44688))


## v0.1.2 (2025-05-14)

### Bug Fixes

- Update readme
  ([`8686199`](https://github.com/mindfiredigital/python-fm-dapi-weaver/commit/8686199110eb74b222ef940f1ce400d0ccecd448))

- Update readme
  ([`abc4771`](https://github.com/mindfiredigital/python-fm-dapi-weaver/commit/abc4771319e1912b51fc02255f2936fcc8092ce9))


## v0.1.1 (2025-05-14)


## v0.1.0 (2025-05-14)

### Bug Fixes

- Add releaseerc
  ([`1970ac8`](https://github.com/mindfiredigital/python-fm-dapi-weaver/commit/1970ac8c22c9164e76147855ebe2a8904c8534f6))

- Add version in init.py
  ([`11ce3f3`](https://github.com/mindfiredigital/python-fm-dapi-weaver/commit/11ce3f33ae8d513eea5229ee1ff54c233e71cfbe))

- Update readme
  ([`fdb655f`](https://github.com/mindfiredigital/python-fm-dapi-weaver/commit/fdb655f6d68fa201bcf90c7615cedff41e60c478))

- Update setup file - Merge pull request #9 from CSWorldTelugu/master
  ([`484feca`](https://github.com/mindfiredigital/python-fm-dapi-weaver/commit/484fecaab3536242e846f3e65e5b4c94058f0f03))

update setup file

- Update setup.cfg
  ([`f03efb7`](https://github.com/mindfiredigital/python-fm-dapi-weaver/commit/f03efb72d7278c84189eec94536720d0e1beb55b))

- Update workflow.yml
  ([`39e803d`](https://github.com/mindfiredigital/python-fm-dapi-weaver/commit/39e803d95b5f80e8b1f319bcf90328c6f466a712))

- Update workflow.yml to raise PR to main from master
  ([`aed95e6`](https://github.com/mindfiredigital/python-fm-dapi-weaver/commit/aed95e6cf095dc811ccfcc9592a99aa4517719e3))

### Features

- Initial release
  ([`7093c0c`](https://github.com/mindfiredigital/python-fm-dapi-weaver/commit/7093c0c0e17ab7883208549989192b9988f17634))
